#[repr(u32)]pub enum ControlAxis {
CONTROL_AXIS_ROLL = 0,
CONTROL_AXIS_PITCH = 1,
CONTROL_AXIS_THRUST = 2,
CONTROL_AXIS_YAW = 3,
}Available on crate feature
dialect-all only.Expand description
Specific axis of pilot control inputs, with order corresponding to x, y, z, r fields in MANUAL_CONTROL message.
Variants
CONTROL_AXIS_ROLL = 0
Roll axis, with positive values corresponding to stick right movement, causing the vehicle to roll right. For helicopters this is lateral cyclic.
CONTROL_AXIS_PITCH = 1
Pitch axis, with positive values corresponding to stick forward movement, causing the vehicle to move nose down. For helicopters this is longitudinal cyclic.
CONTROL_AXIS_THRUST = 2
Main thrust, with positive values corresponding to going faster and higher. For helicopters this is collective.
CONTROL_AXIS_YAW = 3
Yaw axis, with positive values corresponding to pushing right pedal, causing the vehicle to face right direction. For helicopters this is tail collective.
Implementations
Sourceimpl ControlAxis
impl ControlAxis