#[repr(u32)]pub enum MavOdidAuthType {
MAV_ODID_AUTH_TYPE_NONE = 0,
MAV_ODID_AUTH_TYPE_UAS_ID_SIGNATURE = 1,
MAV_ODID_AUTH_TYPE_OPERATOR_ID_SIGNATURE = 2,
MAV_ODID_AUTH_TYPE_MESSAGE_SET_SIGNATURE = 3,
MAV_ODID_AUTH_TYPE_NETWORK_REMOTE_ID = 4,
MAV_ODID_AUTH_TYPE_SPECIFIC_AUTHENTICATION = 5,
}Available on crate feature
dialect-all only.Variants
MAV_ODID_AUTH_TYPE_NONE = 0
No authentication type is specified.
MAV_ODID_AUTH_TYPE_UAS_ID_SIGNATURE = 1
Signature for the UAS (Unmanned Aircraft System) ID.
MAV_ODID_AUTH_TYPE_OPERATOR_ID_SIGNATURE = 2
Signature for the Operator ID.
MAV_ODID_AUTH_TYPE_MESSAGE_SET_SIGNATURE = 3
Signature for the entire message set.
MAV_ODID_AUTH_TYPE_NETWORK_REMOTE_ID = 4
Authentication is provided by Network Remote ID.
MAV_ODID_AUTH_TYPE_SPECIFIC_AUTHENTICATION = 5
The exact authentication type is indicated by the first byte of authentication_data and these type values are managed by ICAO.
Implementations