#[repr(u32)]pub enum MavQshotMode {
MAV_QSHOT_MODE_UNDEFINED = 0,
MAV_QSHOT_MODE_DEFAULT = 1,
MAV_QSHOT_MODE_GIMBAL_RETRACT = 2,
MAV_QSHOT_MODE_GIMBAL_NEUTRAL = 3,
MAV_QSHOT_MODE_GIMBAL_MISSION = 4,
MAV_QSHOT_MODE_GIMBAL_RC_CONTROL = 5,
MAV_QSHOT_MODE_POI_TARGETING = 6,
MAV_QSHOT_MODE_SYSID_TARGETING = 7,
MAV_QSHOT_MODE_CABLECAM_2POINT = 8,
MAV_QSHOT_MODE_HOME_TARGETING = 9,
}Available on crate feature
dialect-all only.Expand description
Enumeration of possible shot modes.
Variants
MAV_QSHOT_MODE_UNDEFINED = 0
Undefined shot mode. Can be used to determine if qshots should be used or not.
MAV_QSHOT_MODE_DEFAULT = 1
Start normal gimbal operation. Is usually used to return back from a shot.
MAV_QSHOT_MODE_GIMBAL_RETRACT = 2
Load and keep safe gimbal position and stop stabilization.
MAV_QSHOT_MODE_GIMBAL_NEUTRAL = 3
Load neutral gimbal position and keep it while stabilizing.
MAV_QSHOT_MODE_GIMBAL_MISSION = 4
Start mission with gimbal control.
MAV_QSHOT_MODE_GIMBAL_RC_CONTROL = 5
Start RC gimbal control.
MAV_QSHOT_MODE_POI_TARGETING = 6
Start gimbal tracking the point specified by Lat, Lon, Alt.
MAV_QSHOT_MODE_SYSID_TARGETING = 7
Start gimbal tracking the system with specified system ID.
MAV_QSHOT_MODE_CABLECAM_2POINT = 8
Start 2-point cable cam quick shot.
MAV_QSHOT_MODE_HOME_TARGETING = 9
Start gimbal tracking the home location.
Implementations
Sourceimpl MavQshotMode
impl MavQshotMode