pub struct AVAILABLE_MODES_DATA {
pub custom_mode: u32,
pub properties: MavModeProperty,
pub number_modes: u8,
pub mode_index: u8,
pub standard_mode: MavStandardMode,
pub mode_name: CharArray<35>,
}dialect-all only.Expand description
Information about a flight mode. The message can be enumerated to get information for all modes, or requested for a particular mode, using MAV_CMD_REQUEST_MESSAGE. Specify 0 in param2 to request that the message is emitted for all available modes or the specific index for just one mode. The modes must be available/settable for the current vehicle/frame type. Each mode should only be emitted once (even if it is both standard and custom). Note that the current mode should be emitted in CURRENT_MODE, and that if the mode list can change then AVAILABLE_MODES_MONITOR must be emitted on first change and subsequently streamed. See https://mavlink.io/en/services/standard_modes.html.
ID: 435
Fields
custom_mode: u32A bitfield for use for autopilot-specific flags
properties: MavModePropertyMode properties.
number_modes: u8The total number of available modes for the current vehicle type.
mode_index: u8The current mode index within number_modes, indexed from 1. The index is not guaranteed to be persistent, and may change between reboots or if the set of modes change.
standard_mode: MavStandardModeStandard mode.
mode_name: CharArray<35>Name of custom mode, with null termination character. Should be omitted for standard modes.
Implementations