pub struct CELLULAR_CONFIG_DATA {
pub enable_lte: u8,
pub enable_pin: u8,
pub pin: CharArray<16>,
pub new_pin: CharArray<16>,
pub apn: CharArray<32>,
pub puk: CharArray<16>,
pub roaming: u8,
pub response: CellularConfigResponse,
}dialect-all only.Expand description
Configure cellular modems. This message is re-emitted as an acknowledgement by the modem. The message may also be explicitly requested using MAV_CMD_REQUEST_MESSAGE.
ID: 336
Fields
enable_lte: u8Enable/disable LTE. 0: setting unchanged, 1: disabled, 2: enabled. Current setting when sent back as a response.
enable_pin: u8Enable/disable PIN on the SIM card. 0: setting unchanged, 1: disabled, 2: enabled. Current setting when sent back as a response.
pin: CharArray<16>PIN sent to the SIM card. Blank when PIN is disabled. Empty when message is sent back as a response.
new_pin: CharArray<16>New PIN when changing the PIN. Blank to leave it unchanged. Empty when message is sent back as a response.
apn: CharArray<32>Name of the cellular APN. Blank to leave it unchanged. Current APN when sent back as a response.
puk: CharArray<16>Required PUK code in case the user failed to authenticate 3 times with the PIN. Empty when message is sent back as a response.
roaming: u8Enable/disable roaming. 0: setting unchanged, 1: disabled, 2: enabled. Current setting when sent back as a response.
response: CellularConfigResponseMessage acceptance response (sent back to GS).
Implementations