pub struct EYE_TRACKING_DATA_DATA {Show 13 fields
pub time_usec: u64,
pub gaze_origin_x: f32,
pub gaze_origin_y: f32,
pub gaze_origin_z: f32,
pub gaze_direction_x: f32,
pub gaze_direction_y: f32,
pub gaze_direction_z: f32,
pub video_gaze_x: f32,
pub video_gaze_y: f32,
pub surface_gaze_x: f32,
pub surface_gaze_y: f32,
pub sensor_id: u8,
pub surface_id: u8,
}dialect-all only.Expand description
Data for tracking of pilot eye gaze. This is the primary message for MARSH_TYPE_EYE_TRACKER.
ID: 52505
Fields
time_usec: u64Timestamp (time since system boot).
gaze_origin_x: f32X axis of gaze origin point, NaN if unknown. The reference system depends on specific application.
gaze_origin_y: f32Y axis of gaze origin point, NaN if unknown. The reference system depends on specific application.
gaze_origin_z: f32Z axis of gaze origin point, NaN if unknown. The reference system depends on specific application.
gaze_direction_x: f32X axis of gaze direction vector, expected to be normalized to unit magnitude, NaN if unknown. The reference system should match origin point.
gaze_direction_y: f32Y axis of gaze direction vector, expected to be normalized to unit magnitude, NaN if unknown. The reference system should match origin point.
gaze_direction_z: f32Z axis of gaze direction vector, expected to be normalized to unit magnitude, NaN if unknown. The reference system should match origin point.
video_gaze_x: f32Gaze focal point on video feed x value (normalized 0..1, 0 is left, 1 is right), NaN if unknown
video_gaze_y: f32Gaze focal point on video feed y value (normalized 0..1, 0 is top, 1 is bottom), NaN if unknown
surface_gaze_x: f32Gaze focal point on surface x value (normalized 0..1, 0 is left, 1 is right), NaN if unknown
surface_gaze_y: f32Gaze focal point on surface y value (normalized 0..1, 0 is top, 1 is bottom), NaN if unknown
sensor_id: u8Sensor ID, used for identifying the device and/or person tracked. Set to zero if unknown/unused.
surface_id: u8Identifier of surface for 2D gaze point, or an identified region when surface point is invalid. Set to zero if unknown/unused.
Implementations