pub struct GNSS_INTEGRITY_DATA {
pub system_errors: GpsSystemErrorFlags,
pub raim_hfom: u16,
pub raim_vfom: u16,
pub id: u8,
pub authentication_state: GpsAuthenticationState,
pub jamming_state: GpsJammingState,
pub spoofing_state: GpsSpoofingState,
pub raim_state: GpsRaimState,
pub corrections_quality: u8,
pub system_status_summary: u8,
pub gnss_signal_quality: u8,
pub post_processing_quality: u8,
}dialect-all only.Expand description
Information about key components of GNSS receivers, like signal authentication, interference and system errors.
ID: 441
Fields
system_errors: GpsSystemErrorFlagsErrors in the GPS system.
raim_hfom: u16Horizontal expected accuracy using satellites successfully validated using RAIM.
raim_vfom: u16Vertical expected accuracy using satellites successfully validated using RAIM.
id: u8GNSS receiver id. Must match instance ids of other messages from same receiver.
authentication_state: GpsAuthenticationStateSignal authentication state of the GPS system.
jamming_state: GpsJammingStateSignal jamming state of the GPS system.
spoofing_state: GpsSpoofingStateSignal spoofing state of the GPS system.
raim_state: GpsRaimStateThe state of the RAIM processing.
corrections_quality: u8An abstract value representing the estimated quality of incoming corrections, or 255 if not available.
system_status_summary: u8An abstract value representing the overall status of the receiver, or 255 if not available.
gnss_signal_quality: u8An abstract value representing the quality of incoming GNSS signals, or 255 if not available.
post_processing_quality: u8An abstract value representing the estimated PPK quality, or 255 if not available.
Implementations