pub struct MLRS_RADIO_LINK_INFORMATION_DATA {Show 14 fields
pub tx_frame_rate: u16,
pub rx_frame_rate: u16,
pub tx_ser_data_rate: u16,
pub rx_ser_data_rate: u16,
pub target_system: u8,
pub target_component: u8,
pub mavtype: MlrsRadioLinkType,
pub mode: u8,
pub tx_power: i8,
pub rx_power: i8,
pub mode_str: CharArray<6>,
pub band_str: CharArray<6>,
pub tx_receive_sensitivity: u8,
pub rx_receive_sensitivity: u8,
}dialect-all only.Expand description
Radio link information. Tx: ground-side device, Rx: vehicle-side device. The values of the fields in this message do normally not or only slowly change with time, and for most times the message can be send at a low rate, like 0.2 Hz. If values change then the message should temporarily be send more often to inform the system about the changes. The target_system field should normally be set to the system id of the system the link is connected to, typically the flight controller. The target_component field can normally be set to 0, so that all components of the system can receive the message.
ID: 60046
Fields
tx_frame_rate: u16Frame rate in Hz (frames per second) for Tx to Rx transmission. 0: unknown.
rx_frame_rate: u16Frame rate in Hz (frames per second) for Rx to Tx transmission. Normally equal to tx_packet_rate. 0: unknown.
tx_ser_data_rate: u16Maximum data rate of serial stream in bytes/s for Tx to Rx transmission. 0: unknown. UINT16_MAX: data rate is 64 KBytes/s or larger.
rx_ser_data_rate: u16Maximum data rate of serial stream in bytes/s for Rx to Tx transmission. 0: unknown. UINT16_MAX: data rate is 64 KBytes/s or larger.
target_system: u8System ID (ID of target system, normally flight controller).
target_component: u8Component ID (normally 0 for broadcast).
mavtype: MlrsRadioLinkTypeRadio link type. 0: unknown/generic type.
mode: u8Operation mode. Radio link dependent. UINT8_MAX: ignore/unknown.
tx_power: i8Tx transmit power in dBm. INT8_MAX: unknown.
rx_power: i8Rx transmit power in dBm. INT8_MAX: unknown.
mode_str: CharArray<6>Operation mode as human readable string. Radio link dependent. Terminated by NULL if the string length is less than 6 chars and WITHOUT NULL termination if the length is exactly 6 chars - applications have to provide 6+1 bytes storage if the mode is stored as string. Use a zero-length string if not known.
band_str: CharArray<6>Frequency band as human readable string. Radio link dependent. Terminated by NULL if the string length is less than 6 chars and WITHOUT NULL termination if the length is exactly 6 chars - applications have to provide 6+1 bytes storage if the mode is stored as string. Use a zero-length string if not known.
tx_receive_sensitivity: u8Receive sensitivity of Tx in inverted dBm. 1..255 represents -1..-255 dBm, 0: unknown.
rx_receive_sensitivity: u8Receive sensitivity of Rx in inverted dBm. 1..255 represents -1..-255 dBm, 0: unknown.
Implementations