pub struct STORM32_GIMBAL_MANAGER_CONTROL_PITCHYAW_DATA {
pub pitch: f32,
pub yaw: f32,
pub pitch_rate: f32,
pub yaw_rate: f32,
pub device_flags: GimbalDeviceFlags,
pub manager_flags: MavStorm32GimbalManagerFlags,
pub target_system: u8,
pub target_component: u8,
pub gimbal_id: u8,
pub client: MavStorm32GimbalManagerClient,
}dialect-all only.Expand description
Message to a gimbal manager to control the gimbal tilt and pan angles. Angles and rates can be set to NaN according to use case. A gimbal device is never to react to this message.
ID: 60013
Fields
pitch: f32Pitch/tilt angle (positive: tilt up). NaN to be ignored.
yaw: f32Yaw/pan angle (positive: pan the right). NaN to be ignored. The frame is determined by the GIMBAL_DEVICE_FLAGS_YAW_IN_xxx_FRAME flags.
pitch_rate: f32Pitch/tilt angular rate (positive: tilt up). NaN to be ignored.
yaw_rate: f32Yaw/pan angular rate (positive: pan to the right). NaN to be ignored. The frame is determined by the GIMBAL_DEVICE_FLAGS_YAW_IN_xxx_FRAME flags.
device_flags: GimbalDeviceFlagsGimbal device flags to be applied (UINT16_MAX to be ignored). Same flags as used in GIMBAL_DEVICE_SET_ATTITUDE.
manager_flags: MavStorm32GimbalManagerFlagsGimbal manager flags to be applied (0 to be ignored).
target_system: u8System ID
target_component: u8Component ID
gimbal_id: u8Gimbal ID of the gimbal manager to address (component ID or 1-6 for non-MAVLink gimbal, 0 for all gimbals). Send command multiple times for more than one but not all gimbals.
client: MavStorm32GimbalManagerClientClient which is contacting the gimbal manager (must be set).
Implementations