pub struct RANGING_BEACON_DATA {Show 15 fields
pub time_usec: u64,
pub range: u32,
pub lat: i32,
pub lon: i32,
pub alt: f32,
pub hacc_est: u32,
pub vacc_est: u32,
pub range_accuracy: u32,
pub beacon_id: u16,
pub carrier_freq: u16,
pub target_system: u8,
pub target_component: u8,
pub alt_type: RangingBeaconAltType,
pub sequence: u8,
pub status: RangingBeaconStatusFlag,
}dialect-all only.Expand description
Range information from a radio beacon for trilateration-based positioning. This message is telemetry intended for consumption by an autopilot (MAVLink does not define the mechanism used to determine the range).
ID: 513
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
range: u32Range measurement between a beacon and a vehicle.
lat: i32Beacon latitude (WGS84).
lon: i32Beacon longitude (WGS84).
alt: f32Beacon altitude (frame defined in alt_type).
hacc_est: u32Beacon 1-sigma horizontal accuracy estimate.
vacc_est: u32Beacon 1-sigma vertical accuracy estimate.
range_accuracy: u32Estimated 1-sigma range measurement accuracy.
beacon_id: u16ID of the ranging beacon/station.
carrier_freq: u16Ranging carrier frequency
target_system: u8System ID.
target_component: u8Component ID.
alt_type: RangingBeaconAltTypeAltitude frame for alt field. RANGING_BEACON_ALT_TYPE_WGS84 (0) preferred.
sequence: u8Measurement sequence number.
status: RangingBeaconStatusFlagRanging beacon status.
Implementations